==> distronode-core-2.16.1.tar.gz: distronode-core-2.16.1/test/units/plugins/lookup/test_ini.py <==
# -*- coding: utf-8 -*-
# (c) 2015, Toshio Kuratomi <tkuratomi@khulnasoft.com>
#
# This file is part of Distronode
#
# Distronode is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Distronode is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Distronode.  If not, see <http://www.gnu.org/licenses/>.

# Make coding more python3-ish
from __future__ import (absolute_import, division, print_function)
__metaclass__ = type

from units.compat import unittest
from distronode.plugins.lookup.ini import _parse_params


class TestINILookup(unittest.TestCase):

    # Currently there isn't a new-style
    old_style_params_data = (
        # Simple case
        dict(
            term=u'keyA section=sectionA file=/path/to/file',
            expected=[u'file=/path/to/file', u'keyA', u'section=sectionA'],
        ),
        dict(
            term=u'keyB section=sectionB with space file=/path/with/embedded spaces and/file',
            expected=[u'file=/path/with/embedded spaces and/file', u'keyB', u'section=sectionB with space'],
        ),
        dict(
            term=u'keyC section=sectionC file=/path/with/equals/cn=com.distronode',
            expected=[u'file=/path/with/equals/cn=com.distronode', u'keyC', u'section=sectionC'],
        ),
        dict(
            term=u'keyD section=sectionD file=/path/with space and/equals/cn=com.distronode',
            expected=[u'file=/path/with space and/equals/cn=com.distronode', u'keyD', u'section=sectionD'],
        ),
        dict(
            term=u'keyE section=sectionE file=/path/with/unicode/くらとみ/file',
            expected=[u'file=/path/with/unicode/くらとみ/file', u'keyE', u'section=sectionE'],
        ),
        dict(
            term=u'keyF section=sectionF file=/path/with/utf 8 and spaces/くらとみ/file',
            expected=[u'file=/path/with/utf 8 and spaces/くらとみ/file', u'keyF', u'section=sectionF'],
        ),
    )

    def test_parse_parameters(self):
        pvals = {'file': '', 'section': '', 'key': '', 'type': '', 're': '', 'default': '', 'encoding': ''}
        for testcase in self.old_style_params_data:
            # print(testcase)
            params = _parse_params(testcase['term'], pvals)
            params.sort()
            self.assertEqual(params, testcase['expected'])

==> distronode-core-2.17.0.dev0.tar.gz: distronode-core-2.17.0.dev0/test/units/plugins/lookup/test_ini.py <==
# -*- coding: utf-8 -*-
# (c) 2015, Toshio Kuratomi <tkuratomi@distronode.github.io>
#
# This file is part of Distronode
#
# Distronode is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Distronode is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Distronode.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import annotations

from units.compat import unittest
from distronode.plugins.lookup.ini import _parse_params


class TestINILookup(unittest.TestCase):

    # Currently there isn't a new-style
    old_style_params_data = (
        # Simple case
        dict(
            term=u'keyA section=sectionA file=/path/to/file',
            expected=[u'file=/path/to/file', u'keyA', u'section=sectionA'],
        ),
        dict(
            term=u'keyB section=sectionB with space file=/path/with/embedded spaces and/file',
            expected=[u'file=/path/with/embedded spaces and/file', u'keyB', u'section=sectionB with space'],
        ),
        dict(
            term=u'keyC section=sectionC file=/path/with/equals/cn=com.distronode',
            expected=[u'file=/path/with/equals/cn=com.distronode', u'keyC', u'section=sectionC'],
        ),
        dict(
            term=u'keyD section=sectionD file=/path/with space and/equals/cn=com.distronode',
            expected=[u'file=/path/with space and/equals/cn=com.distronode', u'keyD', u'section=sectionD'],
        ),
        dict(
            term=u'keyE section=sectionE file=/path/with/unicode/くらとみ/file',
            expected=[u'file=/path/with/unicode/くらとみ/file', u'keyE', u'section=sectionE'],
        ),
        dict(
            term=u'keyF section=sectionF file=/path/with/utf 8 and spaces/くらとみ/file',
            expected=[u'file=/path/with/utf 8 and spaces/くらとみ/file', u'keyF', u'section=sectionF'],
        ),
    )

    def test_parse_parameters(self):
        pvals = {'file': '', 'section': '', 'key': '', 'type': '', 're': '', 'default': '', 'encoding': ''}
        for testcase in self.old_style_params_data:
            # print(testcase)
            params = _parse_params(testcase['term'], pvals)
            params.sort()
            self.assertEqual(params, testcase['expected'])
